#[repr(transparent)]pub struct MacAddress(pub [u8; 32]);Expand description
UEFI Media Access Control (MAC) address.
UEFI supports multiple network protocols and hardware types, not just Ethernet. Some of them may use MAC addresses longer than 6 bytes. To be protocol-agnostic and future-proof, the UEFI spec chooses a maximum size that can hold any supported media access control address.
In most cases, this is just a typical [u8; 6] Ethernet style MAC
address with the rest of the bytes being zero.
Conversions and Relation to [core::net]
There is no matching type in [core::net] but the following [From]
implementations exist:
[u8; 6]<->MacAddress[u8; 32]->MacAddress
Tuple Fields
0: [u8; 32]Implementations
Sourceimpl MacAddress
impl MacAddress
Sourcepub fn into_ethernet_addr(self) -> [u8; 6]
pub fn into_ethernet_addr(self) -> [u8; 6]
Interpret the MAC address as normal 6-byte MAC address, as used in Ethernet.